@@ -1,7 +1,7 @@
 /* toolfunc.h
  * converter for BLINKENmini movies
  *  - converts movies between different file formats
- * Copyright (C) 2002 sphaera & 1stein (http://blinkenmini.1stein.no-ip.com/)
+ * Copyright (C) 2002 sphaera & 1stein (blinkenmini@schuermans.info, https://blinkenmini.schuermans.info/)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,6 +23,9 @@
 
 #include <stdio.h>
 
+#define min( a, b ) ( (a) < (b) ? (a) : (b) )
+#define max( a, b ) ( (a) > (b) ? (a) : (b) )
+
 //read a line and truncate if too long
 //return-value: 0 ok, 1 line truncated
 int ReadLine( FILE * pFile, char * pBuffer, unsigned int BufferSize );
